/*
 * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it would be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * Further, this software is distributed without any warranty that it is
 * free of the rightful claim of any third person regarding infringement
 * or the like.  Any license provided herein, whether implied or
 * otherwise, applies only to this software file.  Patent licenses, if
 * any, provided herein do not apply to combinations of this program with
 * other software, or any other product whatsoever.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write the Free Software Foundation, Inc., 59
 * Temple Place - Suite 330, Boston MA 02111-1307, USA.
 * 
 * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
 * Mountain View, CA  94043, or:
 * 
 * http://www.sgi.com 
 * 
 * For further information regarding this notice, see: 
 * 
 * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
 */

/*
 * app1.c
 *
 * Simple program to demonstrate use of the PCP trace performance metrics
 * domain agent (PMDA(3)).  This agent needs to be installed before metrics
 * can be made available via the performance metrics namespace (PMNS(4)),
 * and the Performance Metrics Collector Daemon (PMCD(1)).
 *
 * Once this program is running, the trace PMDA metrics & instances can be
 * viewed through PCP monitor tools such as pmchart(1), pmgadgets(1), and
 * pmview(1).  To view the help text associated with each of these metrics,
 * use:
 *   $ pminfo -tT trace
 */

#ident "$Id: app1.c,v 1.13 2000/08/21 06:26:16 mg Exp $"

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <pcp/trace.h>


int
main(int argc, char **argv)
{
    int		sts;
    char	*prog;

    prog = argv[0];
    sts = pmtracestate(PMTRACE_STATE_API|PMTRACE_STATE_COMMS|PMTRACE_STATE_PDU);
    fprintf(stderr, "%s: start: %s (state=0x%x)\n", prog,
	pmtraceerrstr(0), sts);	/* force call to all library symbols */

    if ((sts = pmtracebegin("simple")) < 0) {
	fprintf(stderr, "%s: pmtracebegin error: %s\n",
		prog, pmtraceerrstr(sts));
	exit(1);
    }
    if (sleep(2) != 0) {
	fprintf(stderr, "%s: sleep prematurely awaken\n", prog);
	pmtraceabort("simple");
    }
    if ((sts = pmtraceend("simple")) < 0) {
	fprintf(stderr, "%s: pmtraceend error: %s\n",
		prog, pmtraceerrstr(sts));
	exit(1);
    }

    if ((sts = pmtracebegin("ascanbe")) < 0) {
	fprintf(stderr, "%s: pmtracebegin error: %s\n",
		prog, pmtraceerrstr(sts));
	exit(1);
    }
    sleep(1);
    if ((sts = pmtraceend("ascanbe")) < 0) {
	fprintf(stderr, "%s: pmtraceend error: %s\n",
		prog, pmtraceerrstr(sts));
	exit(1);
    }

    if ((sts = pmtraceobs("observe", 101.0)) < 0) {
	fprintf(stderr, "%s: pmtraceobs error: %s\n",
		prog, pmtraceerrstr(sts));
	exit(1);
    }

    if ((sts = pmtracecounter("counter", 101.1)) < 0) {
	fprintf(stderr, "%s: pmtracecounter error: %s\n",
		prog, pmtraceerrstr(sts));
	exit(1);
    }

    if ((sts = pmtracepoint("imouttahere")) < 0) {
	fprintf(stderr, "%s: pmtracepoint error: %s\n",
		prog, pmtraceerrstr(sts));
	exit(1);
    }

    exit(0);
}
